@@ -100,7 +100,7 @@ module Diagrams.Backend.SVG
   , B
     -- for rendering options specific to SVG
   , Options(..), sizeSpec, svgDefinitions, idPrefix, svgAttributes, generateDoctype
-  , svgClass, svgId, svgTitle
+  , svgClass, svgId, svgTitle, svgAttr
   , SVGFloat
 
   , renderSVG
@@ -279,26 +279,29 @@ rtree (Node n rs) = case n of
   RStyle sty                    -> R $ local (over style (<> sty)) r
   RAnnot (OpacityGroup o)       -> R $ g_ [Opacity_ <<- toText o] <$> r
   RAnnot (Href uri)             -> R $ a_ [XlinkHref_ <<- T.pack uri] <$> r
-  RAnnot (KeyVal ("class",v))   -> R $ with <$> r <*> pure [Class_ <<- T.pack v]
-  RAnnot (KeyVal ("id",v))      -> R $ with <$> r <*> pure [Id_ <<- T.pack v]
   RAnnot (KeyVal ("title",v))   -> R $ do
     e <- r
     pure $ g_ [] $ e <> title_ [] (toElement v)
+  RAnnot (KeyVal (attr,v))      -> R $ with <$> r <*> pure [makeAttribute (T.pack attr) (T.pack v)]
   _                             -> R r
   where
     R r = foldMap rtree rs
 
 -- | Set the id for a particular SVG diagram
 svgId :: SVGFloat n => String -> QDiagram SVG V2 n Any -> QDiagram SVG V2 n Any
-svgId = curry keyVal "id"
+svgId = svgAttr "id"
 
 -- | Set the class for a particular SVG diagram
 svgClass :: SVGFloat n => String -> QDiagram SVG V2 n Any -> QDiagram SVG V2 n Any
-svgClass = curry keyVal "class"
+svgClass = svgAttr "class"
 
 -- | Set the title text for a particular SVG diagram
 svgTitle :: SVGFloat n => String -> QDiagram SVG V2 n Any -> QDiagram SVG V2 n Any
-svgTitle = curry keyVal "title"
+svgTitle = svgAttr "title"
+
+-- | Set an arbitrary attribute for a particular SVG diagram
+svgAttr :: SVGFloat n => String -> String -> QDiagram SVG V2 n Any -> QDiagram SVG V2 n Any
+svgAttr attr = curry keyVal attr
 
 -- | Lens onto the size of the svg options.
 sizeSpec :: Lens' (Options SVG V2 n) (SizeSpec V2 n)
